Struct rummage::CargoTarget

source ·
pub struct CargoTarget {
    pub profile: String,
    pub host: String,
    pub target: String,
    pub family: String,
    pub os: String,
    pub arch: String,
    pub pointer_width: String,
    pub endian: String,
    pub features: String,
}
How Cargo was configured while building the crate containing the crate containing the info! invocation

Fields

profile: String

Typically either “debug” or “release”

host: String

The target triple of the environment performing the compilation

target: String

The target triple of the environment the built artifact is intended for

family: String

The “family” of the target, eg “unix”

os: String

The specific OS within the target family, eg “linux”

arch: String

The CPU architecture of the target, eg “x86_64”

pointer_width: String

The number of bits in a pointer on the target platform, eg “64”.

endian: String

The endianness of the target platform, eg “little”

features: String

A comma separated list of the features of the target platform that the compilation is using, eg “fxsr,sse,sse2”

Implementations