pub struct CrateInfo {
pub git_commit_hash: String,
pub is_git_repo_dirty: bool,
pub bin_name: String,
pub crate_name: String,
pub crate_version: String,
}Expand description
Information about the crate that contains the info! invocation
Fields
git_commit_hash: StringThe full SHA256 commit hash of the git repository
is_git_repo_dirty: boolWhether the git repository is in a dirty state / has uncommitted modifications
bin_name: StringThe name of the binary that the crate that has the info! invocation is being built into
crate_name: Stringcrate_version: StringImplementations