Struct rummage::CargoTarget
source · pub struct CargoTarget {
pub profile: String,
pub host: String,
pub target: String,
pub family: String,
pub os: String,
pub arch: String,
pub pointer_width: String,
pub endian: String,
pub features: String,
}Expand description
How Cargo was configured while building the crate containing the crate containing the info!
invocation
Fields
profile: StringTypically either “debug” or “release”
host: StringThe target triple of the environment performing the compilation
target: StringThe target triple of the environment the built artifact is intended for
family: StringThe “family” of the target, eg “unix”
os: StringThe specific OS within the target family, eg “linux”
arch: StringThe CPU architecture of the target, eg “x86_64”
pointer_width: StringThe number of bits in a pointer on the target platform, eg “64”.
endian: StringThe endianness of the target platform, eg “little”
features: StringA comma separated list of the features of the target platform that the compilation is using, eg “fxsr,sse,sse2”
Implementations
sourceimpl CargoTarget
impl CargoTarget