pub struct CargoTarget {
pub profile: String,
pub host: String,
pub target: String,
pub family: String,
pub os: String,
pub arch: String,
pub pointer_width: String,
pub endian: String,
pub features: String,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Instruments this type with the provided
Span, returning an
Instrumented wrapper.
Read more
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.